import sbt._

import Keys._
import AndroidKeys._

object General {
  val settings = Defaults.defaultSettings ++ Seq (
    name := "Notepadv1",
    version := "0.1",
    scalaVersion := "2.10.0-M1",
    platformName in Android := "android-10",
    scalacOptions in Compile ++= Seq("-deprecation")
  )

  lazy val fullAndroidSettings =
    General.settings ++
    AndroidProject.androidSettings ++
    TypedResources.settings ++
    AndroidMarketPublish.settings ++ Seq (
      keyalias in Android := "change-me",
      libraryDependencies += "org.scalatest" % "scalatest_2.9.1" % "1.6.1" % "test"
    )
}

object AndroidBuild extends Build {
  lazy val main = Project (
    "Notepadv1",
    file("."),
    settings = General.fullAndroidSettings ++ 
    inConfig(Android)(Seq(
        manifestPath <<= (baseDirectory, manifestName) map((s,m) => Seq(s / m)) map (x=>x),
        manifestTemplatePath <<= (baseDirectory, manifestName) (_ / _), 
        mainAssetsPath <<= (baseDirectory, assetsDirectoryName) (_ / _), 
        mainResPath <<= (baseDirectory, resDirectoryName) (_ / _) map (x=>x)  
    )) ++ Seq(
        proguardOption in Android := "-dontnote **"
    ) 
  )

  lazy val tests = Project (
    "tests",
    file("tests"),
    settings = General.settings ++ AndroidTest.androidSettings ++ Seq (
      name := "Notepadv1Tests"
    )
  ) dependsOn main
}
