package com.android.demo.notepad1

import android.app.ListActivity
import android.os.Bundle
import android.view.Menu
import android.view.MenuItem
import android.widget.SimpleCursorAdapter
import android.content.Intent
import android.widget.AdapterView.AdapterContextMenuInfo
import android.view.ContextMenu.ContextMenuInfo
import android.view.ContextMenu
import android.widget.ListView
import android.view.View

class Notepadv1 extends ListActivity {
  private[this] final val ACTIVITY_CREATE=0
  private[this] final val ACTIVITY_EDIT=1
  
  private[this] final val INSERT_ID = Menu.FIRST
  private[this] final val DELETE_ID = Menu.FIRST + 1
  
  private[this] var mDbHelper : NotesDbAdapter = _
  
  override def onCreate(savedInstanceState: Bundle) {
    super.onCreate(savedInstanceState)
    setContentView(R.layout.notes_list)
    mDbHelper = NotesDbAdapter(this)
    mDbHelper.open()
    fillData()
    registerForContextMenu(getListView())
  }
  
  override def onCreateOptionsMenu(menu: Menu) = {
    super.onCreateOptionsMenu(menu)
    menu.add(0, INSERT_ID, 0, R.string.menu_insert)
    true
  }
  
  override def onMenuItemSelected(featureId: Int, item: MenuItem) = {
    item.getItemId() match {
      case INSERT_ID =>	{createNote(); true }
      case _ => super.onMenuItemSelected(featureId, item)
    }
  }  
  
  
  override def onCreateContextMenu(menu: ContextMenu, v: View, menuInfo: ContextMenuInfo) {
    super.onCreateContextMenu(menu, v, menuInfo)
    menu.add(0, DELETE_ID, 0, R.string.menu_delete)
  }

  override def onContextItemSelected(item: MenuItem) = {
    item.getItemId() match {
      case DELETE_ID => {
        val info = item.getMenuInfo().asInstanceOf[AdapterContextMenuInfo]
        mDbHelper.deleteNote(info.id)
        fillData()
        true
      }
      case _ => super.onContextItemSelected(item)
    }
  }  
  
   
  override protected def onListItemClick(l: ListView, v: View, position: Int, id: Long) {
    super.onListItemClick(l, v, position, id)
    val i = new Intent(this, classOf[NoteEdit])
    i.putExtra(mDbHelper.KEY_ROWID, id)
    startActivityForResult(i, ACTIVITY_EDIT)
  }

  override protected def onActivityResult(requestCode: Int, resultCode: Int, intent: Intent) {
        super.onActivityResult(requestCode, resultCode, intent)
        fillData()
  } 
  
  private def createNote() {
    val i = new Intent(this, classOf[NoteEdit])
    startActivityForResult(i, ACTIVITY_CREATE)
  }  
  
  private def fillData() {
	// Get all of the notes from the database and create the item list
	val notesCursor = mDbHelper.fetchAllNotes()
	startManagingCursor(notesCursor)
	
	var from = Array[String](mDbHelper.KEY_TITLE)
	var to = Array[Int](R.id.text1)
	
	// Now create an array adapter and set it to display using our row
	val notes = new SimpleCursorAdapter(this, R.layout.notes_row, notesCursor, from, to)
	setListAdapter(notes)
  }  
  
}
