package com.android.demo.notepad1

import android.app.Activity
import android.widget.EditText
import android.widget.Button
import android.os.Bundle
import android.view.View

class NoteEdit extends Activity {
  private[this] var mTitleText: EditText = _
  private[this] var mBodyText: EditText = _
  private[this] var mRowId: Option[Long] = None
  private[this] var mDbHelper: NotesDbAdapter = _
  
  type Activity = android.app.Activity
  object Activity {
    final val RESULT_OK = android.app.Activity.RESULT_OK
  }
  import Activity._
  
  override protected def onCreate(savedInstanceState: Bundle) {
    super.onCreate(savedInstanceState)
    mDbHelper = new NotesDbAdapter(this)
    mDbHelper.open()

    setContentView(R.layout.note_edit)
    setTitle(R.string.edit_note)

    mTitleText = findViewById(R.id.title).asInstanceOf[EditText]
    mBodyText = findViewById(R.id.body).asInstanceOf[EditText]

    val confirmButton = findViewById(R.id.confirm).asInstanceOf[Button]

    mRowId = None
    if(savedInstanceState != null)
      mRowId =  Some(savedInstanceState.getSerializable(mDbHelper.KEY_ROWID).asInstanceOf[Long])
    
    if (mRowId == None) {
      val extras = getIntent().getExtras()
      if(extras != null)
        mRowId =  Some(extras.getLong(mDbHelper.KEY_ROWID))
	}

	populateFields()

    confirmButton.setOnClickListener(new View.OnClickListener() {

        def onClick(view: View) {
            setResult(RESULT_OK)
            finish()
        }

    })
  }

  private[this] def populateFields() {
	if (mRowId != None) {
	  val note = mDbHelper.fetchNote(mRowId.get)
	  startManagingCursor(note)
	  mTitleText.setText(note.getString(note.getColumnIndexOrThrow(mDbHelper.KEY_TITLE)))
	  mBodyText.setText(note.getString(note.getColumnIndexOrThrow(mDbHelper.KEY_BODY)))
	}
  }
	
  override protected def onSaveInstanceState(outState: Bundle) {
    super.onSaveInstanceState(outState)
    saveState()
    outState.putSerializable(mDbHelper.KEY_ROWID, mRowId)
  }
	
  override protected def onPause() {
    super.onPause()
	saveState()
  }
	
  override protected def onResume() {
	super.onResume()
	populateFields()
  }
	
  private[this] def saveState() {
    val title = mTitleText.getText().toString()
    val body = mBodyText.getText().toString()

    if (mRowId == None) {
        val id = mDbHelper.createNote(title, body)
        if (id > 0) {
            mRowId = Some(id)
        }
    } else {
        mDbHelper.updateNote(mRowId.get, title, body)
    }
  }

}