package com.android.demo.notepad1
import android.content.ContentValues
import android.database.sqlite.SQLiteOpenHelper
import android.database.sqlite.SQLiteDatabase
import android.content.Context
import android.util.Log

class NotesDbAdapter(val ctx: Context) {

  final val KEY_TITLE = "title"
  final val KEY_BODY = "body"
  final val KEY_ROWID = "_id"  
  
  private[this] final val TAG = "NotesDbAdapter"
  private[this] var mDbHelper: DatabaseHelper = _  
  private[this] var mDb: SQLiteDatabase = _ 
  
  private[this] final val DATABASE_CREATE =
  	"create table notes (_id integer primary key autoincrement, " +
  	"title text not null, body text not null);"
        
  private[this] final val DATABASE_NAME = "data"
  private[this] final val DATABASE_TABLE = "notes"
  private[this] final val DATABASE_VERSION = 2
  
  class DatabaseHelper(val context: Context) extends SQLiteOpenHelper(context, DATABASE_NAME, null, DATABASE_VERSION) {

    override def onCreate(db: SQLiteDatabase) = db.execSQL(DATABASE_CREATE)
    
    override def onUpgrade(db: SQLiteDatabase, oldVersion: Int, newVersion: Int) {
      Log.w(TAG, "Upgrading database from version " + oldVersion + " to " + newVersion + ", which will destroy all old data")
      db.execSQL("DROP TABLE IF EXISTS notes")
      onCreate(db)   
    }
    
  }
  private[this] object DatabaseHelper {
    def apply(context: Context) = new DatabaseHelper(context)
  }
  
  def open() {
    mDbHelper = DatabaseHelper(ctx)
    mDb = mDbHelper.getWritableDatabase()
  }

  def close() {
    mDbHelper.close()
  }
  
  def createNote(title: String,body: String) = {
    val initialValues = new ContentValues()
    initialValues.put(KEY_TITLE, title)
    initialValues.put(KEY_BODY, body)
    mDb.insert(DATABASE_TABLE, null, initialValues)
  }
  
  def deleteNote(rowId: Long) = {
    mDb.delete(DATABASE_TABLE, KEY_ROWID + "=" + rowId, null) > 0
  }
  
  def fetchAllNotes() = {
    mDb.query(DATABASE_TABLE, Array[String](KEY_ROWID, KEY_TITLE, KEY_BODY), null, null, null, null, null)
  }
  
  def fetchNote(rowId: Long) = {
    val mCursor =  mDb.query(true, DATABASE_TABLE, Array[String](KEY_ROWID,
                    KEY_TITLE, KEY_BODY), KEY_ROWID + "=" + rowId, null,
                    null, null, null, null)
    if (mCursor != null) {
      mCursor.moveToFirst();
    }
    mCursor
  }
  
  def updateNote(rowId: Long, title: String, body: String)= {
    val args = new ContentValues()
    args.put(KEY_TITLE, title)
    args.put(KEY_BODY, body)

    mDb.update(DATABASE_TABLE, args, KEY_ROWID + "=" + rowId, null) > 0
  }
 
}

object NotesDbAdapter {
  def apply(ctx: Context) = new NotesDbAdapter(ctx)
}
